@@ -1,6 +1,6 @@
 import sys
 
-def main(args):
+def main():
   commands = ['home', 'next', 'back', 'check', 'progress']
 
   print('\nUsage:')
@@ -12,4 +12,4 @@ def main(args):
   print()
 
 if __name__ == "__main__":
-    main(sys.argv)
\ No newline at end of file
+    main()
\ No newline at end of file
